Learn R Programming

factualR (version 0.5)

factualR-package: thin wrapper for the Factual.com server API

Description

Per the Factual.com website, "Factual is a platform where anyone can share and mash open, living data on any subject." The data is in the form of tables and is accessible via REST API. The factualR package is a thin wrapper around the Factual.com API, to make it even easier for people working with R to explore Factual.com data sets.

For now, this package supports read-only requests ("read" and "schema"); a future revision may support modification of Factual.com data ("input" API calls).

Arguments

Details

Package:
factualR
Type:
Package
Version:
1.0
Date:
2010-12-26
License:
Apache 2.0
LazyLoad:
yes
Depends:
methods RJSONIO RCurl
To use this package, please refer to the functions createFactualConnection, factualGetSchema, and factualRead. That documentation includes examples.

Also, please refer to the developer documentation for the "Server API" at http://wiki.developer.factual.com/

References

http://wiki.developer.factual.com/

See Also

createFactualConnection factualGetSchema factualRead